# coding: utf-8

"""
    SDK

    算想云对开发者提供的API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sxwl_client.api.scheduler_api_api import SchedulerApiApi


class TestSchedulerApiApi(unittest.TestCase):
    """SchedulerApiApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SchedulerApiApi()

    def tearDown(self) -> None:
        pass

    def test_finetune(self) -> None:
        """Test case for finetune

        """
        pass

    def test_inference_deploy(self) -> None:
        """Test case for inference_deploy

        """
        pass

    def test_job_create(self) -> None:
        """Test case for job_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
